==> phpwiki-1.2.6.tbz: www/data-dist/phpwiki/locale/it/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Nome utente o password errata.";
$locale["You are about to remove '%s' permanently!"] =
   "Stai per rimuovere %s";
$locale["Click %shere%s to remove the page now."] =
   "Per rimuovere la pagina clicca %squa%s";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Altrimenti premi il bottone \"Precedente\" sul tuo browser";
$locale["Function not yet implemented."] =
   "Funzione non implementata.";
$locale["Remove page"] =
   "Rimuovi la pagina";
$locale["Removed page '%s' succesfully."] =
   "La pagina '%s' &egrave; stata rimossa correttamente.";
$locale["templates/browse.html"] =
   "locale/it/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/it/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/it/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/it/templates/message.html";
$locale["./pgsrc"] =
   "locale/it/pgsrc";
$locale["WikiDiff::apply: line count mismatch: %s != %s"] =
   "WikiDiff::applu: il numero delle linee &egrave; differente: %s != %s";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: fallito";
$locale["WikiDiff::_check: edit sequence is non-optimal"] =
   "WikiDiff::_check: la sequenza di editazione non e` ottimale";
$locale["WikiDiff Okay: LCS = %s"] =
   "WikiDiff Ok: LCS = %s";
$locale["Current page:"] =
   "Pagina corrente:";
$locale["version %s"] =
   "versione %s";
$locale["last modified on %s"] =
   "Ultima modifica: %s";
$locale["by %s"] =
   "di %s";
$locale["None"] =
   "Nessuno";
$locale["Archived page:"] =
   "Pagina archiviata:";
$locale["Versions are identical"] =
   "Le versioni sono identiche";
$locale["Diff of %s."] =
   "Differenza di %s";
$locale["FrontPage"] =
   "PaginaPrincipale";
$locale["Describe %s here."] =
   "Descrivi %s qui";
$locale["Copy of %s"] =
   "Copia di %s";
$locale["No page name passed into editpage!"] =
   "Nessuna pagina &grave; passata a modificapagina";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Questa pagina &grave; stata bloccata dall'amministratore e non pu&ograve; essere modificata";
$locale["Sorry for the inconvenience."] =
   "Scusa per l'inconveniente.";
$locale["Problem while editing %s"] =
   "Si sono verificati problemi durante la modifica %s";
$locale["Searching for \"%s\" ....."] =
   "Sto cercando \"%s\" .....";
$locale["%d matches found in %d pages."] =
   "Ho trovato %d occorrente in %d pagine.";
$locale["Full Text Search Results"] =
   "Risultati della ricerca su tutto il testo";
$locale["Cannot establish connection to database, giving up."] =
   "Non riesco a stabilire una connessione col database, abbandono.";
$locale["Error message: %s"] =
   "Messaggio d'errore: %s";
$locale["Cannot open database %s, giving up."] =
   "Non riesco ad aprire il database %s, abbandono.";
$locale["Insert/update failed: %s"] =
   "Inserimento/aggiornamento fallito: %s";
$locale["Delete on %s failed: %s"] =
   "Cancellazione su %s fallita: %s";
$locale["Insert into %s failed: %s"] =
   "Inserimento in %s fallito: %s";
$locale["MySQL error: %s"] =
   "Errore di MySQL: %s";
$locale["Error writing page '%s'"] =
   "Errore durante il salvataggio della pagina '%s'";
$locale["Cannot delete '%s' from table '%s'"] =
   "Non posso cancellare '%s' dalla tabella '%s'";
$locale["Enter a page name"] =
   "Scrivi un nome di una pagina";
$locale["Go"] =
   "Vai";
$locale["Show the page source and references"] =
   "Mostra il sorgente della pagina e le sue referenze";
$locale["PageInfo"] =
   "InformazioniDellaPagina";
$locale["Page name '%s' is not in the database"] =
   "La pagina '%s' non e` presente nel database";
$locale["Current version"] =
   "Versione corrente";
$locale["Archived version"] =
   "Versione archiviata";
$locale["RecentChanges"] =
   "ModificheRecenti";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki non &egrave; riuscito a salvare i tuoi cambiamenti perch&egrave; un altro utente ha cambiato la pagina mentre la stavi modificando. Se il salvataggio viene comunque fatto, i cambiamenti dell'altro utente verranno persi.";
$locale["In order to recover from this situation follow these steps:"] =
   "Per risolvere questa situazione segui questi passi:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Usa il pulsante <b>Precedente</b> del tuo browser per tornarealla pagina di modifica";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Copia le tue modifiche nella clipboard o temporaneamente in unaltro posto (es: un editor di testo)";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Aggiorna</b> la pagina. Dovresti vedere l'ultima versione senzamodifiche";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Cambia ancora il file ed installa le tue modifiche dalla clipboard (o dall'editor di testo)";
$locale["Press <b>Save</b> again."] =
   "Premi ancora <b>Salva</b>";
$locale["Problem while updating %s"] =
   "Problemi durante l'aggiornamento %s";
$locale["Thank you for editing %s."] =
   "Grazie per le modifiche! %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "La tua cura verso il dettaglio &egrave; molto apprezzata.";
$locale["Title Search Results"] =
   "Risultati della ricerca su tutto il testo";
$locale["Inserting page %s, version %s from %s"] =
   "Sto inserendo la pagina %s, versione %s da %s";
$locale["WikiFatalError"] =
   "ErroreFataleDiWiki";
$locale["Search"] =
   "Ricerca";
$locale["%d best incoming links:"] =
   "%d migliori link in entrata:";
$locale["%d best outgoing links:"] =
   "%s migliori link in uscita:";
$locale["%d most popular nearby:"] =
   "%d pi&ugrave; popolari:";

;?>

==> phpwiki-1.2.10_1.tbz: www/data-dist/phpwiki/locale/it/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Nome utente o password errata.";
$locale["You are about to remove '%s' permanently!"] =
   "Stai per rimuovere %s";
$locale["Click %shere%s to remove the page now."] =
   "Per rimuovere la pagina clicca %squa%s";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Altrimenti premi il bottone \"Precedente\" sul tuo browser";
$locale["Function not yet implemented."] =
   "Funzione non implementata.";
$locale["Remove page"] =
   "Rimuovi la pagina";
$locale["Removed page '%s' succesfully."] =
   "La pagina '%s' &egrave; stata rimossa correttamente.";
$locale["templates/browse.html"] =
   "locale/it/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/it/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/it/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/it/templates/message.html";
$locale["./pgsrc"] =
   "locale/it/pgsrc";
$locale["WikiDiff::apply: line count mismatch: %s != %s"] =
   "WikiDiff::applu: il numero delle linee &egrave; differente: %s != %s";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: fallito";
$locale["WikiDiff::_check: edit sequence is non-optimal"] =
   "WikiDiff::_check: la sequenza di editazione non e` ottimale";
$locale["WikiDiff Okay: LCS = %s"] =
   "WikiDiff Ok: LCS = %s";
$locale["Current page:"] =
   "Pagina corrente:";
$locale["version %s"] =
   "versione %s";
$locale["last modified on %s"] =
   "Ultima modifica: %s";
$locale["by %s"] =
   "di %s";
$locale["None"] =
   "Nessuno";
$locale["Archived page:"] =
   "Pagina archiviata:";
$locale["Versions are identical"] =
   "Le versioni sono identiche";
$locale["Diff of %s."] =
   "Differenza di %s";
$locale["FrontPage"] =
   "PaginaPrincipale";
$locale["Describe %s here."] =
   "Descrivi %s qui";
$locale["Copy of %s"] =
   "Copia di %s";
$locale["No page name passed into editpage!"] =
   "Nessuna pagina &grave; passata a modificapagina";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Questa pagina &grave; stata bloccata dall'amministratore e non pu&ograve; essere modificata";
$locale["Sorry for the inconvenience."] =
   "Scusa per l'inconveniente.";
$locale["Problem while editing %s"] =
   "Si sono verificati problemi durante la modifica %s";
$locale["Searching for \"%s\" ....."] =
   "Sto cercando \"%s\" .....";
$locale["%d matches found in %d pages."] =
   "Ho trovato %d occorrente in %d pagine.";
$locale["Full Text Search Results"] =
   "Risultati della ricerca su tutto il testo";
$locale["Cannot establish connection to database, giving up."] =
   "Non riesco a stabilire una connessione col database, abbandono.";
$locale["Error message: %s"] =
   "Messaggio d'errore: %s";
$locale["Cannot open database %s, giving up."] =
   "Non riesco ad aprire il database %s, abbandono.";
$locale["Insert/update to table 'wiki' failed: %s"] =
   "Inserimento/aggiornamento su 'wiki' fallito: %s";
$locale["Delete on %s failed: %s"] =
   "Cancellazione su %s fallita: %s";
$locale["Insert into %s failed: %s"] =
   "Inserimento in %s fallito: %s";
$locale["Insert/update into table 'archive' failed: %s"] =
   "Inserimento/aggiornamento su 'archive' fallito: %s";
$locale["MSSQL error: %s"] =
   "Errore di MSSQL: %s";
$locale["Insert/Update failed: %s"] =
   "Inserimento/aggiornamento fallito: %s";
$locale["Cannot delete '%s' from table '%s'"] =
   "Non posso cancellare '%s' dalla tabella '%s'";
$locale["MySQL error: %s"] =
   "Errore di MySQL: %s";
$locale["Error writing page '%s'"] =
   "Errore durante il salvataggio della pagina '%s'";
$locale["Enter a page name"] =
   "Scrivi un nome di una pagina";
$locale["Go"] =
   "Vai";
$locale["Show the page source and references"] =
   "Mostra il sorgente della pagina e le sue referenze";
$locale["PageInfo"] =
   "InformazioniDellaPagina";
$locale["Page name '%s' is not in the database"] =
   "La pagina '%s' non e` presente nel database";
$locale["Current version"] =
   "Versione corrente";
$locale["Archived version"] =
   "Versione archiviata";
$locale["RecentChanges"] =
   "ModificheRecenti";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki non &egrave; riuscito a salvare i tuoi cambiamenti perch&egrave; un altro utente ha cambiato la pagina mentre la stavi modificando. Se il salvataggio viene comunque fatto, i cambiamenti dell'altro utente verranno persi.";
$locale["In order to recover from this situation follow these steps:"] =
   "Per risolvere questa situazione segui questi passi:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Usa il pulsante <b>Precedente</b> del tuo browser per tornarealla pagina di modifica";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Copia le tue modifiche nella clipboard o temporaneamente in unaltro posto (es: un editor di testo)";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Aggiorna</b> la pagina. Dovresti vedere l'ultima versione senzamodifiche";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Cambia ancora il file ed installa le tue modifiche dalla clipboard (o dall'editor di testo)";
$locale["Press <b>Save</b> again."] =
   "Premi ancora <b>Salva</b>";
$locale["Problem while updating %s"] =
   "Problemi durante l'aggiornamento %s";
$locale["Thank you for editing %s."] =
   "Grazie per le modifiche! %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "La tua cura verso il dettaglio &egrave; molto apprezzata.";
$locale["Title Search Results"] =
   "Risultati della ricerca su tutto il testo";
$locale["Inserting page %s, version %s from %s"] =
   "Sto inserendo la pagina %s, versione %s da %s";
$locale["WikiFatalError"] =
   "ErroreFataleDiWiki";
$locale["Search"] =
   "Ricerca";
$locale["%d best incoming links:"] =
   "%d migliori link in entrata:";
$locale["%d best outgoing links:"] =
   "%s migliori link in uscita:";
$locale["%d most popular nearby:"] =
   "%d pi&ugrave; popolari:";

;?>
